@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                           )--------------------
-# Copyright (c) 2014-2021 Beartype authors.
+# Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -68,8 +68,8 @@ This private submodule is *not* intended for importation by downstream callers.
 # ....................{ IMPORTS                           }....................
 from beartype.meta import URL_ISSUES
 from beartype.roar._roarexc import (
-    BeartypeCallHintPepParamException,
-    BeartypeCallHintPepReturnException,
+    BeartypeCallHintParamViolation,
+    BeartypeCallHintReturnViolation,
     _BeartypeCallHintPepRaiseException,
     _BeartypeCallHintPepRaiseDesynchronizationException,
 )
@@ -92,12 +92,12 @@ from beartype._data.hint.pep.sign.datapepsignset import (
 from beartype._decor._error._errorsleuth import CauseSleuth
 from beartype._util.hint.utilhinttest import die_unless_hint
 from beartype._util.text.utiltextlabel import (
-    prefix_callable_decorated_param_value,
+    prefix_callable_decorated_arg_value,
     prefix_callable_decorated_return_value,
 )
 from beartype._util.text.utiltextmunge import suffix_unless_suffixed
 from beartype._util.text.utiltextrepr import represent_object
-from beartype._util.utiltyping import TypeException
+from beartype._data.datatyping import TypeException
 from typing import Callable, Dict, NoReturn, Optional
 
 # See the "beartype.cave" submodule for further commentary.
@@ -207,9 +207,9 @@ def raise_pep_call_exception(
 
     Raises
     ----------
-    BeartypeCallHintPepParamException
+    BeartypeCallHintParamViolation
         If the object failing to satisfy this hint is a parameter.
-    BeartypeCallHintPepReturnException
+    BeartypeCallHintReturnViolation
         If the object failing to satisfy this hint is a return value.
     BeartypeDecorHintPepException
         If the type hint annotating this object is *not* PEP-compliant.
@@ -244,17 +244,17 @@ def raise_pep_call_exception(
     # If the name of this parameter is the magic string implying the passed
     # object to be a return value, set the above local variables appropriately.
     if pith_name == 'return':
-        exception_cls = BeartypeCallHintPepReturnException
+        exception_cls = BeartypeCallHintReturnViolation
         exception_prefix = prefix_callable_decorated_return_value(
             func=func, return_value=pith_value)
     # Else, the passed object is a parameter. In this case, set the above local
     # variables appropriately.
     else:
-        exception_cls = BeartypeCallHintPepParamException
-        exception_prefix = prefix_callable_decorated_param_value(
+        exception_cls = BeartypeCallHintParamViolation
+        exception_prefix = prefix_callable_decorated_arg_value(
             func=func,
-            param_name=pith_name,
-            param_value=pith_value,
+            arg_name=pith_name,
+            arg_value=pith_value,
         )
 
     # If this parameter or return value is unannotated, raise an exception.
