@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                           )--------------------
-# Copyright (c) 2014-2021 Beartype authors.
+# Copyright (c) 2014-2022 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -22,7 +22,7 @@ from beartype._util.hint.pep.proposal.pep484.utilpep484ref import (
 from beartype._util.mod.utilmodimport import import_module_attr
 from beartype._util.mod.utilmodule import get_object_module_name
 from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_7
-from beartype._util.utiltyping import TypeException
+from beartype._data.datatyping import TypeException
 from typing import Any, Union
 
 # See the "beartype.cave" submodule for further commentary.
@@ -114,7 +114,7 @@ def die_unless_hint_pep484585_forwardref(
     # If this is *NOT* a forward reference type hint, raise an exception.
     if not isinstance(hint, HINT_PEP484585_FORWARDREF_TYPES):
         raise BeartypeDecorHintForwardRefException(
-            f'{exception_prefix}{repr(hint)} not forward reference '
+            f'{exception_prefix}type hint {repr(hint)} not forward reference '
             f'(i.e., neither string nor "typing.ForwardRef" instance).'
         )
 
