@@ -123,11 +123,13 @@ if IS_PYTHON_AT_LEAST_3_8:
         # Return either:
         # * If this hint is the "typing.Protocol" superclass directly
         #   parametrized by one or more type variables (e.g.,
-        #   "typing.Protocol[S, T]"), true. For unknown and presumably
-        #   uninteresting reasons, *ALL* possible objects satisfy this
-        #   superclass. Ergo, this superclass and *ALL* parametrizations of
-        #   this superclass are synonymous with the "object" root superclass.
+        #   "typing.Protocol[S, T]"), true. Since this superclass can *ONLY* be
+        #   parametrized by type variables, a simple test suffices.
         # * Else, "None".
+        #
+        # For unknown and uninteresting reasons, *ALL* possible objects satisfy
+        # this superclass. Ergo, this superclass and *ALL* parametrizations of
+        # this superclass are synonymous with the "object" root superclass.
         return repr(hint).startswith('typing.Protocol[') or None
 
 
@@ -408,11 +410,10 @@ def _init() -> None:
     # ..................{ IMPORTS                           }..................
     # Defer Python version-specific imports.
     from beartype._util.mod.lib.utiltyping import import_typing_attr_or_none
-    from beartype.typing import List
-    from typing import (
+    from beartype.typing import (
         AnyStr,
+        List,
         Protocol,
-        runtime_checkable,
     )
 
     # ..................{ GLOBALS                           }..................
@@ -429,7 +430,7 @@ def _init() -> None:
 
     # PEP-compliant type hint matching file handles opened in either text or
     # binary mode.
-    @runtime_checkable
+    # @runtime_checkable
     class _Pep544IO(Protocol[AnyStr]):
         # The body of this class is copied wholesale from the existing
         # non-functional "typing.IO" class.
@@ -526,7 +527,7 @@ def _init() -> None:
     # Note that PEP 544 explicitly requires *ALL* protocols (including
     # protocols subclassing protocols) to explicitly subclass the "Protocol"
     # superclass, in violation of both sanity and usability. (Thanks, guys.)
-    @runtime_checkable
+    # @runtime_checkable
     class _Pep544TextIO(_Pep544IO[str], Protocol):
         # The body of this class is copied wholesale from the existing
         # non-functional "typing.TextIO" class.
